@@ -84,11 +84,6 @@ static GnomeUIInfo view1_menu_uiinfo[] =
 	 cb_toggle_threads, NULL, NULL, 0, NULL,
 	 't', GDK_CONTROL_MASK
 	},
-	{
-	 GNOME_APP_UI_ITEM, N_("Open _Files"), N_("View a process' open files"),
-	 cb_show_open_files, NULL, NULL, 0, 0,
-	 'f', GDK_CONTROL_MASK
-	},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide process from list"),
@@ -102,10 +97,15 @@ static GnomeUIInfo view1_menu_uiinfo[] =
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("Open the memory maps associated with the process"),
+	 GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("Open the memory maps associated with a process"),
 	 cb_show_memory_maps, NULL, NULL, 0, NULL,
 	 'm', GDK_CONTROL_MASK
 	},
+	{
+	 GNOME_APP_UI_ITEM, N_("Open _Files"), N_("View the files opened by a process"),
+	 cb_show_open_files, NULL, NULL, 0, 0,
+	 'f', GDK_CONTROL_MASK
+	},
 	GNOMEUIINFO_END
 };
 
@@ -137,11 +137,6 @@ static GnomeUIInfo popup_menu_uiinfo[] =
 	 cb_kill_process, NULL, NULL, 0, NULL,
 	 0, 0
 	},
-	{
- 	  GNOME_APP_UI_ITEM, N_("Open _Files"), N_("View process' open files"),
-	 popup_menu_show_open_files, NULL, NULL, 0, 0,
-	 0, 0
-	},
 	GNOMEUIINFO_SEPARATOR,
 	{
  	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the order of priority of process"),
@@ -160,6 +155,11 @@ static GnomeUIInfo popup_menu_uiinfo[] =
 	 cb_show_memory_maps, NULL, NULL, 0, NULL,
 	 0, 0
 	},
+	{
+ 	  GNOME_APP_UI_ITEM, N_("Open _Files"), N_("View the files opened by the process"),
+	 popup_menu_show_open_files, NULL, NULL, 0, 0,
+	 0, 0
+	},
 	GNOMEUIINFO_END
 };
 
@@ -755,7 +755,9 @@ update_sensitivity (ProcData *data, gboolean sensitivity)
 	/*View->Hidden Processes*/
 	gtk_widget_set_sensitive (view1_menu_uiinfo[4].widget, sensitivity);
 	/*View->Memory Maps*/
-	gtk_widget_set_sensitive (view1_menu_uiinfo[5].widget, sensitivity);
+	gtk_widget_set_sensitive (view1_menu_uiinfo[6].widget, sensitivity);
+	/*View->Open Files*/
+	gtk_widget_set_sensitive (view1_menu_uiinfo[7].widget, sensitivity);	
 }
 
 static void		
